==> granite-spring-2.1.0.GA-sources.jar: org/granite/tide/spring/security/AclIdentity3.java <==
/*
  GRANITE DATA SERVICES
  Copyright (C) 2007-2008 ADEQUATE SYSTEMS SARL

  This file is part of Granite Data Services.

  Granite Data Services is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 3 of the License, or (at your
  option) any later version.

  Granite Data Services is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with this library; if not, see <http://www.gnu.org/licenses/>.
*/

package org.granite.tide.spring.security;

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import org.granite.tide.annotations.TideEnabled;
import org.springframework.security.acls.domain.DefaultPermissionFactory;
import org.springframework.security.acls.domain.ObjectIdentityRetrievalStrategyImpl;
import org.springframework.security.acls.domain.PermissionFactory;
import org.springframework.security.acls.domain.SidRetrievalStrategyImpl;
import org.springframework.security.acls.model.Acl;
import org.springframework.security.acls.model.AclService;
import org.springframework.security.acls.model.NotFoundException;
import org.springframework.security.acls.model.ObjectIdentity;
import org.springframework.security.acls.model.ObjectIdentityRetrievalStrategy;
import org.springframework.security.acls.model.Permission;
import org.springframework.security.acls.model.Sid;
import org.springframework.security.acls.model.SidRetrievalStrategy;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;


/**
 * 	@author William DRAI
 * 
 * 	Adapted from the Spring security JSP taglib
 */
@TideEnabled
public class AclIdentity3 extends Identity3 {
    
    private SidRetrievalStrategy sidRetrievalStrategy = null;
    private ObjectIdentityRetrievalStrategy objectIdentityRetrievalStrategy = null;
    private AclService aclService = null;
    
    
    public AclIdentity3() {
    	sidRetrievalStrategy = new SidRetrievalStrategyImpl();
    	objectIdentityRetrievalStrategy = new ObjectIdentityRetrievalStrategyImpl();
    }
    
    public void setSidRetrievalStrategy(SidRetrievalStrategy strategy) {
    	sidRetrievalStrategy = strategy;
    }
    
    public void setObjectIdentityRetrievalStrategy(ObjectIdentityRetrievalStrategy strategy) {
    	objectIdentityRetrievalStrategy = strategy;
    }
    
    public void setAclService(AclService aclService) {
    	this.aclService = aclService;
    }
    
    
    public boolean hasPermission(Object entity, String permissions) {
    	if (entity == null)
    		return true;
    	
        List<Permission> requiredPermissions = null;
        try {
            requiredPermissions = parsePermissionsString(permissions);
        } 
        catch (NumberFormatException nfe) {
            throw new RuntimeException(nfe);
        }

        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        if (authentication == null)
        	return false;

        List<Sid> sids = sidRetrievalStrategy.getSids(authentication);
        ObjectIdentity oid = objectIdentityRetrievalStrategy.getObjectIdentity(entity);

        // Obtain aclEntrys applying to the current Authentication object
        try {
            Acl acl = aclService.readAclById(oid, sids);

            return acl.isGranted(requiredPermissions, sids, false);
        } 
        catch (NotFoundException nfe) {
            return false;
        }
    }
    
    @SuppressWarnings("unchecked")
	private List<Permission> parsePermissionsString(String integersString) throws NumberFormatException {
    	final List permissions = new ArrayList();   // Voluntarily not typed to avoid compilation problem with both Spring 2 and Spring 3
    	final StringTokenizer tokenizer;
    	tokenizer = new StringTokenizer(integersString, ",", false);
    	
    	PermissionFactory pf = new DefaultPermissionFactory();
    	while (tokenizer.hasMoreTokens()) {
    		String integer = tokenizer.nextToken();
    		permissions.add(pf.buildFromMask(new Integer(integer).intValue()));
    	}
    	
    	return permissions;
    }
}

==> granite-spring-2.2.0.GA-sources.jar: org/granite/tide/spring/security/AclIdentity3.java <==
/*
  GRANITE DATA SERVICES
  Copyright (C) 2007-2010 ADEQUATE SYSTEMS SARL

  This file is part of Granite Data Services.

  Granite Data Services is free software; you can redistribute it and/or modify
  it under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  Granite Data Services is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library General Public License
  for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; if not, see <http://www.gnu.org/licenses/>.
*/

package org.granite.tide.spring.security;

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import org.granite.tide.annotations.TideEnabled;
import org.springframework.security.acls.domain.DefaultPermissionFactory;
import org.springframework.security.acls.domain.ObjectIdentityRetrievalStrategyImpl;
import org.springframework.security.acls.domain.PermissionFactory;
import org.springframework.security.acls.domain.SidRetrievalStrategyImpl;
import org.springframework.security.acls.model.Acl;
import org.springframework.security.acls.model.AclService;
import org.springframework.security.acls.model.NotFoundException;
import org.springframework.security.acls.model.ObjectIdentity;
import org.springframework.security.acls.model.ObjectIdentityRetrievalStrategy;
import org.springframework.security.acls.model.Permission;
import org.springframework.security.acls.model.Sid;
import org.springframework.security.acls.model.SidRetrievalStrategy;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;


/**
 * 	@author William DRAI
 * 
 * 	Adapted from the Spring security JSP taglib
 */
@TideEnabled
public class AclIdentity3 extends Identity3 {
    
    private SidRetrievalStrategy sidRetrievalStrategy = null;
    private ObjectIdentityRetrievalStrategy objectIdentityRetrievalStrategy = null;
    private AclService aclService = null;
    
    
    public AclIdentity3() {
    	sidRetrievalStrategy = new SidRetrievalStrategyImpl();
    	objectIdentityRetrievalStrategy = new ObjectIdentityRetrievalStrategyImpl();
    }
    
    public void setSidRetrievalStrategy(SidRetrievalStrategy strategy) {
    	sidRetrievalStrategy = strategy;
    }
    
    public void setObjectIdentityRetrievalStrategy(ObjectIdentityRetrievalStrategy strategy) {
    	objectIdentityRetrievalStrategy = strategy;
    }
    
    public void setAclService(AclService aclService) {
    	this.aclService = aclService;
    }
    
    
    public boolean hasPermission(Object entity, String permissions) {
    	if (entity == null)
    		return true;
    	
        List<Permission> requiredPermissions = null;
        try {
            requiredPermissions = parsePermissionsString(permissions);
        } 
        catch (NumberFormatException nfe) {
            throw new RuntimeException(nfe);
        }

        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        if (authentication == null)
        	return false;

        List<Sid> sids = sidRetrievalStrategy.getSids(authentication);
        ObjectIdentity oid = objectIdentityRetrievalStrategy.getObjectIdentity(entity);

        // Obtain aclEntrys applying to the current Authentication object
        try {
            Acl acl = aclService.readAclById(oid, sids);

            return acl.isGranted(requiredPermissions, sids, false);
        } 
        catch (NotFoundException nfe) {
            return false;
        }
    }
    
    @SuppressWarnings({ "unchecked", "rawtypes" })
	private List<Permission> parsePermissionsString(String integersString) throws NumberFormatException {
    	final List permissions = new ArrayList();   // Voluntarily not typed to avoid compilation problem with both Spring 2 and Spring 3
    	final StringTokenizer tokenizer;
    	tokenizer = new StringTokenizer(integersString, ",", false);
    	
    	PermissionFactory pf = new DefaultPermissionFactory();
    	while (tokenizer.hasMoreTokens()) {
    		String integer = tokenizer.nextToken();
    		permissions.add(pf.buildFromMask(new Integer(integer).intValue()));
    	}
    	
    	return permissions;
    }
}
